@@ -31,8 +31,8 @@ class Profile(PaymentechResource):
     status: Optional[str] = Field(alias="Status", max_length=2)
     card_number: Optional[str] = Field(alias="CCAccountNum", max_length=22)
     card_expiration: Optional[str] = Field(alias="CCExpireDate", max_length=6)
-    bank_account_type: Optional[str] = Field(alias="ECPAccountType", max_length=1)
     bank_account_number: Optional[str] = Field(alias="ECPAccountDDA", max_length=17)
+    bank_account_type: Optional[str] = Field(alias="ECPAccountType", max_length=1)
     bank_routing_number: Optional[str] = Field(alias="ECPAccountRT", max_length=9)
     bank_payment_delivery_method: Optional[str] = Field(alias="ECPBankPmtDlv", max_length=1)
     soft_descriptor_merchant: Optional[str] = Field(alias="SDMerchantName", max_length=25)
@@ -60,23 +60,18 @@ class Profile(PaymentechResource):
 
     def read(self):
         self.validate_customer_reference_number("read")
-
         self.customer_profile_action = "R"
 
         return self.transact()
 
     def update(self):
         self.validate_customer_reference_number("update")
-
         self.customer_profile_action = "U"
-        self.customer_profile_order_override = "NO"
-        self.customer_profile_from_order = "S"
 
         return self.transact()
 
     def delete(self):
         self.validate_customer_reference_number("delete")
-
         self.customer_profile_action = "D"
 
         return self.transact()
